cmd

package
v0.0.0-...-2467275 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 10, 2023 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddArticle

func AddArticle(url string)

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func ListArticles

func ListArticles()

func Login

func Login(reset bool)

func ModifyItemPrompt

func ModifyItemPrompt(id string)

Types

This section is empty.

Jump to