Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddArticle ¶
func AddArticle(url string)
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func ListArticles ¶
func ListArticles()
func ModifyItemPrompt ¶
func ModifyItemPrompt(id string)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.